@@ -1117,6 +1117,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdatePolicy(self, request):
+        """This API (UpdatePolicy) is used to update a policy.
+
+        :param request: Request instance for UpdatePolicy.
+        :type request: :class:`tencentcloud.cam.v20190116.models.UpdatePolicyRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.UpdatePolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdatePolicy", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdatePolicyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateRoleConsoleLogin(self, request):
         """This API is used to modify a role’s login permissions.
 
